pub struct InertiaResponse {
pub component: String,
pub props: Value,
}Expand description
An Inertia response that adapts its format based on request headers.
Convert to an actual response using into_response_with(headers, url, config).
Fields
component: Stringprops: ValueImplementations
Sourceimpl InertiaResponse
impl InertiaResponse
Sourcepub fn into_response_with(
self,
request_headers: &HeaderMap,
url: &str,
config: &InertiaConfig,
) -> Response
pub fn into_response_with( self, request_headers: &HeaderMap, url: &str, config: &InertiaConfig, ) -> Response
Build the final HTTP response.
Called by the Inertia middleware which has access to the request headers and URL.