Module string

Module string 

Structs

Email
Validates that a value is a valid email address.
Hostname
Validates that a value is a valid hostname (RFC 1123).
Ip
Validates that a value is a valid IP address.
Length
Validates that a string length is within a given range.
NotBlank
Validates that a value is not blank (not empty and not only whitespace).
Regex
Validates that a value matches a regular expression pattern.
Url
Validates that a value is a valid URL.